macro_rules! up {
($a:tt) => { ... };
() => { ... };
}Expand description
Moves the cusor up the specified amount of characters. If no arguments are given, defaults to 1.
macro_rules! up {
($a:tt) => { ... };
() => { ... };
}Moves the cusor up the specified amount of characters. If no arguments are given, defaults to 1.